@@ -10,19 +10,14 @@ from requests.exceptions import ConnectionError, ConnectTimeout, HTTPError, Read
 from tqdm.auto import tqdm
 from tqdm.utils import CallbackIOWrapper
 
-from todus3 import __app_name__
+from todus3 import ErrorCode, __app_name__
 from todus3.errors import AbortError
 from todus3.s3 import get_real_url, reserve_url
-from todus3.util import (
-    ErrorCode,
-    decode_content,
-    generate_token,
-    shorten_name,
-    tqdm_logging,
-)
+from todus3.util import decode_content, generate_token, shorten_name, tqdm_logging
 
 DEFAULT_TIMEOUT: float = 30  # seconds
 CHUNK_SIZE = 1024
+AUTH_ENDPOINT = "https://auth.todus.cu/v2/auth"
 logger = logging.getLogger(__app_name__)
 
 
@@ -79,8 +74,10 @@ class ToDusClient:
             + b"\x12\x96\x01"
             + generate_token(150).encode("utf-8")
         )
-        url = "https://auth.todus.cu/v2/auth/users.reserve"
-        with self.session.post(url, data=data, headers=headers) as resp:
+        url = f"{AUTH_ENDPOINT}/users.reserve"
+        with self.session.post(
+            url, data=data, headers=headers, timeout=DEFAULT_TIMEOUT
+        ) as resp:
             resp.raise_for_status()
 
     def request_code(self, phone_number: str) -> None:
@@ -98,8 +95,10 @@ class ToDusClient:
             + b"\x1a\x06"
             + code.encode("utf-8")
         )
-        url = "https://auth.todus.cu/v2/auth/users.register"
-        with self.session.post(url, data=data, headers=headers) as resp:
+        url = f"{AUTH_ENDPOINT}/users.register"
+        with self.session.post(
+            url, data=data, headers=headers, timeout=DEFAULT_TIMEOUT
+        ) as resp:
             resp.raise_for_status()
             if b"`" in resp.content:
                 index = resp.content.index(b"`") + 1
@@ -128,8 +127,10 @@ class ToDusClient:
             + b"\x1a\x05"
             + self.version_code.encode("utf-8")
         )
-        url = "https://auth.todus.cu/v2/auth/token"
-        with self.session.post(url, data=data, headers=headers) as resp:
+        url = f"{AUTH_ENDPOINT}/token"
+        with self.session.post(
+            url, data=data, headers=headers, timeout=DEFAULT_TIMEOUT
+        ) as resp:
             resp.raise_for_status()
             # Default Encoding for HTML4 ISO-8859-1 (Latin-1)
             content = decode_content(resp.content)
@@ -210,10 +211,15 @@ class ToDusClient:
             ) as ex:
                 tqdm_logging(logging.ERROR, str(ex))
                 retry += 1
+                tqdm_logging(logging.INFO, f"Retrying: {retry}...")
                 if retry == max_retry:
                     self.error_code = ErrorCode.CLIENT
-                    raise ValueError(f"Failed to upload part {index} ({size:,}B): {ex}")
-                tqdm_logging(logging.INFO, f"Retrying: {retry}...")
+                    tqdm_logging(
+                        logging.ERROR,
+                        f"Failed to upload part {index} ({size:,} Bytes): {ex}",
+                    )
+                    self.exit = True
+                    break
                 time.sleep(5)
             else:
                 up_done = True
@@ -262,27 +268,12 @@ class ToDusClient:
                 # For now we skip slow connections when reach the Timeout
                 # https://docs.python-requests.org/en/master/user/quickstart/#timeouts
                 with open(file_save, "wb") as file_stream:
-                    try:
-                        for chunk in resp.iter_content(chunk_size=CHUNK_SIZE):
-                            if self.exit:
-                                break
-                            progress_bar.update(len(chunk))
-                            file_stream.write(chunk)
-                    except (
-                        ConnectionError,
-                        ConnectTimeout,
-                        HTTPError,
-                        ReadTimeout,
-                        socket.timeout,
-                        socket.gaierror,
-                    ):
-                        down_error = True
-
+                    for chunk in resp.iter_content(chunk_size=CHUNK_SIZE):
+                        if self.exit:
+                            break
+                        progress_bar.update(len(chunk))
+                        file_stream.write(chunk)
                 progress_bar.close()
-                if self.exit:
-                    raise AbortError("Client has abruptly terminated.")
-                elif down_error:
-                    raise ReadTimeout("Error during download process.", response=resp)
         return size
 
     def download_file(
@@ -306,8 +297,10 @@ class ToDusClient:
                 url = self.task_download_1(token, url)
                 size = self.task_download_2(token, url, filename_path, down_timeout)
             except (
-                AbortError,
+                IOError,
                 HTTPError,
+                ConnectTimeout,
+                ConnectionError,
                 ReadTimeout,
                 socket.timeout,
                 socket.gaierror,
